@@ -23,7 +23,7 @@
 #include "xfce-panel-convenience.h"
 #include "xfce-panel-image.h"
 #include "xfce-panel-macros.h"
-#include "libxfce4panel-alias.h"
+#include "libxfce4panel-visibility.h"
 
 #include "common/panel-private.h"
 
@@ -858,4 +858,4 @@ xfce_panel_image_clear (XfcePanelImage *image)
 
 
 #define __XFCE_PANEL_IMAGE_C__
-#include "libxfce4panel-aliasdef.c"
+#include "libxfce4panel-visibility.c"
