@@ -20,9 +20,9 @@
 #include "config.h"
 #endif
 
-#include "panel/panel-module-factory.h"
-#include "panel/panel-module.h"
-#include "panel/panel-plugin-external-wrapper.h"
+#include "panel-module-factory.h"
+#include "panel-module.h"
+#include "panel-plugin-external-wrapper.h"
 
 #include "common/panel-debug.h"
 #include "common/panel-private.h"
@@ -32,7 +32,7 @@
 #include <libxfce4util/libxfce4util.h>
 
 #ifdef HAVE_GTK_LAYER_SHELL
-#include <gtk-layer-shell/gtk-layer-shell.h>
+#include <gtk-layer-shell.h>
 #else
 #define gtk_layer_is_supported() FALSE
 #endif
