@@ -19,14 +19,15 @@
 #ifndef __XFCE_TASKLIST_PLUGIN_H__
 #define __XFCE_TASKLIST_PLUGIN_H__
 
-#include <libxfce4panel/libxfce4panel.h>
+#include "libxfce4panel/libxfce4panel.h"
 
 G_BEGIN_DECLS
 
 #define TASKLIST_TYPE_PLUGIN (tasklist_plugin_get_type ())
 G_DECLARE_FINAL_TYPE (TasklistPlugin, tasklist_plugin, TASKLIST, PLUGIN, XfcePanelPlugin)
 
-void tasklist_plugin_register_type (XfcePanelTypeModule *type_module);
+void
+tasklist_plugin_register_type (XfcePanelTypeModule *type_module);
 
 G_END_DECLS
 
